import { render, remove } from 'mcf-components'

import { DefinedObject } from 'mcf-objects/src'

import form from './components/form'
import errorsDialog from './components/errorsDialog'


const uiDefinition = {
  htmlReference: { TYPE: 'string', required: true },

  name: { TYPE: 'string' },
  book: { TYPE: 'enum', availableValues: ['lor', 'sfi', 'tgr'] },

  imageList:    { TYPE: 'array' },
  activityList: { TYPE: 'array', maxLength: 3 },
}
const uiInitialValues = {
  name: '',
  imageList: [],
  activityList: [],
}

export default class UI extends DefinedObject {
  constructor(params, onSubmit) {
    super({
      fields: uiDefinition,
      values: params,
    })

    this.onSubmit = onSubmit
    this.setValue(uiInitialValues)
  }

  checkParams() {
    const errors = []
    if (!this.getValue().name) errors.push('Name')
    if (!this.getValue().book) errors.push('Book')
    if (this.getValue().imageList.length === 0) errors.push('Image')
    if (this.getValue().activityList.length === 0) errors.push('Activity')
    return errors
  }

  manageErrors(errors) {
    remove(this.getValue().htmlReference)
    render(errorsDialog(this, errors), this.getValue().htmlReference)
  }

  renderPage() {
    remove(this.getValue().htmlReference)
    render(form(this), this.getValue().htmlReference)
  }
}
